@@ -1,3 +1,10 @@
+# Copyright (c) 2012, cPanel, Inc.
+# All rights reserved.
+# http://cpanel.net/
+#
+# This is free software; you can redistribute it and/or modify it under the same
+# terms as Perl itself.  See the LICENSE file for further details.
+
 package Mail::Alias::Reader::Parser;
 
 use strict;
@@ -22,15 +29,10 @@ sub _parse_forward_statement {
             push @destinations, $token;
         }
         elsif ( $token->isa('T_COMMA') ) {
-            confess('Unexpected comma') unless $last_token->is_value;
-        }
-        elsif ( $token->isa('T_END') ) {
-            confess('Unexpected end of statement') unless $last_token->is_value;
-
-            last;
+            confess('Unexpected comma') unless $last_token->is_value || $last_token->isa('T_COMMA');
         }
         else {
-            confess("Unexpected $token->{'type'}");
+            confess("Unexpected $token->{'type'}") unless $token->isa('T_END');
         }
 
         $last_token = $token;
@@ -60,10 +62,10 @@ sub _parse_aliases_statement {
             $name = $last_token->{'value'};
         }
         elsif ( $token->isa('T_COMMA') ) {
-            confess('Unexpected comma') unless $last_token->is_value;
+            confess('Unexpected comma') unless $last_token->is_value || $last_token->isa('T_COMMA');
         }
         elsif ( $token->isa('T_END') ) {
-            confess('Unexpected end of aliases statement') unless $last_token->is_value;
+            confess('Unexpected end of aliases statement') unless $last_token->is_value || $last_token->isa('T_COMMA');
 
             last;
         }
@@ -98,4 +100,9 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright(c) 2011 cPanel, Inc.  All rights reserved.
+Copyright (c) 2012, cPanel, Inc.
+All rights reserved.
+http://cpanel.net/
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as Perl itself.  See the LICENSE file for further details.
